==> MoSeka-1.1.1.tar.gz: MoSeka-1.1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'MoSeka',         # How you named your package folder (MyLib)
  packages = ['MoSeka'],   # Chose the same as "name"
  version = '1.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Deep learning framework',   # Give a short description about your library
  author = 'Mohamed elsayed',                   # Type in your name
  author_email = 'mohamedelsayed16397@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Muhamedelsayed/MNiST',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Muhamedelsayed/MNiST/archive/V1.1.1.tar.gz',    # I explain this later on
  keywords = ['Lenet5', 'Framework', 'MNIST'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'pandas',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> MoSeka-1.7.tar.gz: MoSeka-1.7/setup.py <==
from distutils.core import setup
setup(
  name = 'MoSeka',         # How you named your package folder (MyLib)
  packages = ['MoSeka'],   # Chose the same as "name"
  version = '1.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Deep learning framework',   # Give a short description about your library
  author = 'Mohamed elsayed',                   # Type in your name
  author_email = 'mohamedelsayed16397@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Muhamedelsayed/MNiST',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Muhamedelsayed/MNiST/archive/V1.7.tar.gz',    # I explain this later on
  keywords = ['Lenet5', 'Framework', 'MNIST'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'pandas',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
